import { spawn as spawnOrig } from "child_process";
import { rateLimit } from "../utils/index.js";
const spawnDefaults = { shell: false, windowsHide: true, stdio: ["pipe", "pipe", "inherit"] };
const forwardSignal = (child, signal) => {
  const forward = rateLimit(() => child.kill(signal), 100);
  process.on(signal, forward);
  child.on("exit", () => process.off(signal, forward));
};
const spawn = (command, args = [], options = {}) => {
  const env = { ...process.env, ...options.env };
  const child = spawnOrig(command, args, { ...spawnDefaults, ...options, env });
  forwardSignal(child, "SIGINT");
  return child;
};
const run = async (command, args = [], options = {}) => {
  return new Promise((resolve, reject) => {
    const cmd = spawn(command, args, options);
    cmd.once("exit", (code) => code == 0 ? resolve(code) : reject(code));
    cmd.once("err", reject);
  });
};
export {
  run,
  spawn
};
//# sourceMappingURL=spawn.js.map
