import { getMetaEntries } from "./utils.js";
import Logger from "@home-gallery/logger";
const log = Logger("database.media.address");
const keyMapping = {
  hamlet: "city",
  village: "city",
  town: "city"
};
const createAddress = (entry) => {
  const geoReverse = entry.meta?.geoReverse;
  if (!geoReverse) {
    return false;
  } else if (!geoReverse.address) {
    log.warn(`No geo address found for entry ${entry} with geo coordinates ${geoReverse.lat}/${geoReverse.lon}. Skip address`);
    return false;
  }
  const result = {
    addresstype: geoReverse.addresstype
  };
  const address = geoReverse.address;
  const addressKeys = ["country", "state", "hamlet", "village", "town", "city", "road", "house_number"];
  addressKeys.forEach((key) => {
    if (address[key]) {
      const infoKey = keyMapping[key] || key;
      result[infoKey] = address[key];
    }
  });
  return result;
};
const getAddress = (entry) => {
  const metaEntries = getMetaEntries(entry);
  const metaAddress = metaEntries.reduce((address, entry2) => address || createAddress(entry2), false);
  if (metaAddress) {
    return metaAddress;
  }
  const allEntries = [entry, ...entry.sidecars || []];
  const allAddress = allEntries.reduce((address, entry2) => address || createAddress(entry2), false);
  return allAddress ? allAddress : {};
};
const addressMapper = {
  name: "addressMapper",
  mapEntry(entry, media) {
    return { ...media, ...getAddress(entry) };
  }
};
export {
  addressMapper
};
//# sourceMappingURL=address.js.map
