import Logger from "@home-gallery/logger";
const log = Logger("database.media.iptc");
const allEntriesByMetaAndSize = (entry) => [entry, ...entry.sidecars].sort((a, b) => {
  if (a.type != b.type) {
    return b.type == "meta" ? 1 : -1;
  } else if (a.filename.length != b.filename.length) {
    return a.filename.length < b.filename.length ? -1 : 1;
  }
  return a.size < b.size ? 1 : -1;
});
const getIptc = (entry) => {
  const iptc = allEntriesByMetaAndSize(entry).filter((entry2) => entry2.meta.exif).reduce((iptc2, entry2) => {
    const exif = entry2.meta.exif;
    if (!exif.ImageDescription) {
      return iptc2;
    } else if (iptc2.description) {
      log.debug(`Skip image description from ${entry2}: ${exif.ImageDescription}. Description is already set`);
    } else {
      log.trace(`Use image description from ${entry2}: ${exif.ImageDescription}`);
      iptc2.description = exif.ImageDescription;
    }
    return iptc2;
  }, {});
  return iptc;
};
const iptcMapper = {
  name: "iptcMapper",
  mapEntry(entry, media) {
    return { ...media, ...getIptc(entry) };
  }
};
export {
  iptcMapper
};
//# sourceMappingURL=iptc.js.map
