import Vibrant from "node-vibrant";
import Logger from "@home-gallery/logger";
const log = Logger("extractor.vibrant");
import { toPipe, conditionalTask } from "../../stream/task.js";
import { toPlugin } from "../pluginUtils.js";
const vibrantSuffix = "vibrant.json";
async function vibrant(storage, imagePreviewSuffix) {
  const test = (entry) => storage.hasFile(entry, imagePreviewSuffix) && !storage.hasFile(entry, vibrantSuffix);
  const task = async (entry) => {
    const t0 = Date.now();
    const localFile = await storage.createLocalFile(entry, imagePreviewSuffix);
    return new Promise((resolve, reject) => {
      Vibrant.from(localFile.file).getPalette((err, palette) => {
        if (err) {
          return reject(err);
        }
        resolve(palette);
      });
    }).then((palette) => storage.writeFile(entry, vibrantSuffix, palette)).then(() => {
      log.debug(t0, `Extracted vibrant colors from ${entry}`);
    }).catch((err) => {
      log.error(err, `Could not extract vibrant colors of ${entry}: ${err}`);
    }).finally(async () => {
      return localFile?.release();
    });
  };
  return {
    test,
    task
  };
}
const createImagePreviewSuffix = (imagePreviewSizes) => {
  const imageSize = imagePreviewSizes.filter((size) => size <= 256).shift();
  if (!imageSize) {
    log.warn(`Could not find preview image size (<= 256) for vibrant image from preview sizes ${imagePreviewSizes}. Disable vibrant color extraction`);
  }
  return `image-preview-${imageSize || 128}.jpg`;
};
const vibrantPlugin = (manager) => ({
  name: "vibrant",
  phase: "file",
  async create(storage) {
    const context = manager.getContext();
    const { imagePreviewSizes } = context;
    const imagePreviewSuffix = createImagePreviewSuffix(imagePreviewSizes);
    return vibrant(storage, imagePreviewSuffix);
  }
});
const plugin = toPlugin(vibrantPlugin, "vibrantExtractor", ["imagePreviewExtractor"]);
var vibrant_default = plugin;
export {
  vibrant_default as default,
  vibrant
};
//# sourceMappingURL=vibrant.js.map
