import { orAst, andAst, cmpAst, valueAst } from "./ast-factories.js";
import { numericKeys, rangeKeys, textKeys } from "./ast-keys.js";
import { keyAliasMap } from "./ast-aliases.js";
const transformRules = [
  {
    keys: Object.keys(keyAliasMap),
    transform: (ast) => ({ ...ast, key: keyAliasMap[ast.key] })
  },
  {
    types: ["inRange"],
    keys: rangeKeys,
    transform: (ast) => andAst([
      cmpAst(ast.key, ">=", ast.value[0], ast.col),
      cmpAst(ast.key, "<=", ast.value[1], ast.col)
    ], ast.col)
  },
  {
    keys: ["location"],
    transform: (ast) => orAst([
      { ...ast, key: "country" },
      { ...ast, key: "state" },
      { ...ast, key: "city" },
      { ...ast, key: "road" }
    ], ast.col)
  },
  {
    keys: ["geo"],
    transform: (ast) => andAst([
      { ...ast, key: "latitude" },
      { ...ast, key: "longitude" }
    ], ast.col)
  },
  {
    types: ["keyValue"],
    keys: [...numericKeys, ...textKeys],
    transform: (ast) => cmpAst(ast.key, "=", ast.value, ast.col)
  },
  {
    types: ["cmp"],
    keys: ["ratio"],
    ops: ["="],
    matchValue: (v) => ["panorama", "landscape", "square", "portrait"].includes(v),
    transform: (ast) => {
      switch (ast.value.value) {
        case "panorama":
          return cmpAst(ast.key, ">", valueAst("2", ast.value.col), ast.col);
        case "landscape":
          return cmpAst(ast.key, ">", valueAst("1", ast.value.col), ast.col);
        case "square":
          return cmpAst(ast.key, "=", valueAst("1", ast.value.col), ast.col);
        default:
          return cmpAst(ast.key, "<", valueAst("1", ast.value.col), ast.col);
      }
    }
  }
];
export {
  transformRules
};
//# sourceMappingURL=transform-rules.js.map
