import { parse } from "./parser/index.js";
import { stringifyEntry } from "./stringify-entry.js";
import { execQuery } from "./query/index.js";
import { transformAst, transformRules } from "./ast/index.js";
export * from "./parser/index.js";
export * from "./ast/index.js";
import { createFilterMapSort } from "./query/index.js";
import { stringifyAst, transformAst as transformAst2 } from "./ast/index.js";
import { stringifyEntry as stringifyEntry2 } from "./stringify-entry.js";
import { createStringifyEntryCache } from "./stringify-entry-cache.js";
const ignoreUnknownExpressions = () => true;
const throwUnknownExpressions = (ast) => {
  throw new Error(`Unknown expression ${ast.type} with key ${ast.key || "none"} at ${ast.col}`);
};
const defaultOptions = {
  textFn: stringifyEntry,
  unknownExpressionHandler: () => ignoreUnknownExpressions,
  queryErrorHandler(ast, options, reason) {
    return this.unknownExpressionHandler(ast, options);
  },
  plugin: {}
};
const filterEntriesByQuery = async (entries, query, context = {}) => {
  if (!entries || !entries.length || !query) {
    return { entries };
  }
  return parse(query).then((parsedAst) => {
    const ast = transformAst(parsedAst, {}, transformRules);
    return execQuery(entries, ast, { ...defaultOptions, ...context }).then((entries2) => {
      return {
        entries: entries2,
        parsedAst,
        ast
      };
    }).catch((execErr) => {
      const err = new Error(`Failed to execute search query`, { cause: execErr });
      err.ast = ast;
      err.parsedAst = parsedAst;
      return Promise.reject(err);
    });
  });
};
export {
  createFilterMapSort,
  createStringifyEntryCache,
  filterEntriesByQuery,
  ignoreUnknownExpressions,
  stringifyAst,
  stringifyEntry2 as stringifyEntry,
  throwUnknownExpressions,
  transformAst2 as transformAst
};
//# sourceMappingURL=index.js.map
