import { readJsonGzip, writeJsonGzip } from "@home-gallery/common";
function createEntryFilesCache() {
  return {
    type: "entryFilesCache",
    version: 1,
    created: new Date().toISOString(),
    entries: {}
  };
}
function readEntryFilesCache(cacheFilename, cb) {
  readJsonGzip(cacheFilename, cb);
}
function readOrCreateEntryFilesCache(cacheFilename, cb) {
  readEntryFilesCache(cacheFilename, (err, data) => {
    if (err && err.code === "ENOENT") {
      return cb(null, createEntryFilesCache());
    }
    cb(err, data);
  });
}
function writeEntryFilesCache(cacheFilename, data, cb) {
  writeJsonGzip(cacheFilename, { ...data, ...{ created: new Date().toISOString() } }, cb);
}
function updateEntryFilesCache(cacheFilename, entries, cb) {
  if (!entries.length) {
    return cb(null, { entries });
  }
  readOrCreateEntryFilesCache(cacheFilename, (err, data) => {
    if (err) {
      return cb(err);
    }
    entries.forEach(({ sha1sum, files, meta }) => {
      data.entries[sha1sum] = { files, meta };
    });
    writeEntryFilesCache(cacheFilename, data, cb);
  });
}
export {
  createEntryFilesCache,
  readEntryFilesCache,
  readOrCreateEntryFilesCache,
  updateEntryFilesCache,
  writeEntryFilesCache
};
//# sourceMappingURL=entry-files-cache.js.map
