import { through } from "./through.js";
import Logger from "@home-gallery/logger";
const log = Logger("stream.concurrent");
const noop = () => through((entry, _, cb) => cb(null, entry));
const concurrent = (concurrent2, countOffset) => {
  concurrent2 = typeof concurrent2 == "undefined" ? 0 : +concurrent2;
  countOffset = +countOffset || 0;
  if (concurrent2 <= 0) {
    return {
      queueEntry: noop(),
      releaseEntry: noop()
    };
  }
  log.info(`Processing queue is limitted to ${concurrent2} concurrent entries`);
  let count = 0;
  let runningTasks = 0;
  const queue = [];
  const next = () => {
    if (!queue.length || runningTasks >= concurrent2) {
      return;
    }
    const head = queue.shift();
    if (!head.isFlush) {
      runningTasks++;
    }
    head.done();
  };
  const queueEntry = through((entry, _, cb) => {
    const done = () => cb(null, entry);
    queue.push({ entry, done, count: countOffset + count++ });
    next();
  }, (cb) => {
    queue.push({ entry: null, done: cb, isFlush: true });
    next();
  });
  const releaseEntry = through((entry, _, cb) => {
    runningTasks--;
    cb(null, entry);
    next();
  }, (cb) => {
    cb();
  });
  return {
    queueEntry,
    releaseEntry
  };
};
export {
  concurrent
};
//# sourceMappingURL=concurrent.js.map
