import { through } from "./through.js";
import Logger from "@home-gallery/logger";
const log = Logger("stream.pipe");
function processIndicator({ name, intervalMs, totalFn, onTick, logLevel }) {
  name = name || "";
  intervalMs = intervalMs || 1e3 * 10;
  let count = 0;
  let lastCount = 0;
  let lastTime = Date.now();
  const defaultTickFn = ({ name: name2, count: count2, diff }) => {
    const total = totalFn ? totalFn() || 0 : 0;
    const msg = `Processed ${name2 ? name2 + " " : ""}${count2}${total ? ` of ${total} (${(100 * count2 / total).toFixed(1)}%)` : ""} (+${diff})`;
    if (logLevel == "info") {
      log.info(lastTime, msg);
    } else {
      log.debug(lastTime, msg);
    }
  };
  onTick = onTick || defaultTickFn;
  return through(function(data, _, cb) {
    count++;
    const now = Date.now();
    if (now - lastTime > intervalMs) {
      onTick({ name, count, diff: count - lastCount, lastTime });
      lastTime = now;
      lastCount = count;
    }
    this.push(data);
    cb();
  });
}
export {
  processIndicator
};
//# sourceMappingURL=process-indicator.js.map
